@@ -159,6 +159,7 @@ proc xcircuit::setpstype {mode} {
       }
    }
    ::set pstype $mode
+   xcircuit::page encapsulation $mode
 }
 
 proc xcircuit::pageupdate { {subcommand "none"} } {
@@ -432,7 +433,7 @@ button .output.textent.but5 -text Apply -bg beige \
 	-command {xcircuit::page height [.output.textent.txt5 get];\
 	.output.textent.but5 configure -text Okay}
 button .output.textent.but7 -text Apply -bg beige \
-	-command {xcircuit::page size [.output.textent.txt7 get];\
+	-command {xcircuit::page size [.output.textent.txtp get];\
 	.output.textent.but7 configure -text Okay}
 
 bind .output.textent.txt1 <Return> {.output.textent.but1 invoke}
@@ -952,7 +953,7 @@ proc xcircuit::createtoolbar {} {
 		[expr {[winfo rooty .xcircuit.mainframe.toolbar.bco] \
 		- [winfo height .colormenu] / 2}] } \
 	{tk_popup .bordermenu [expr {[winfo rootx \
-		.xcircuit.mainframe.toolbar.toolbarea.bbd] \
+		.xcircuit.mainframe.toolbar.toolbar.bbd] \
 		- [winfo width .bordermenu]}] \
 		[expr {[winfo rooty .xcircuit.mainframe.toolbar.bbd] \
 		- [winfo height .bordermenu] / 2}] } \
@@ -1069,7 +1070,7 @@ set bbox invisible
 set editinplace true
 set pinpositions invisible
 set centerobject true
-set manhattandraw true
+set manhattandraw false
 set polyclosed true
 set bboxtype false
 set substringparam false
@@ -1095,11 +1096,14 @@ $m add command -label "Read XCircuit File" -command {xcircuit::promptloadfile}
 $m add command -label "Import XCircuit PS" -command {xcircuit::promptimportfile}
 $m add command -label "Import background PS" -command {xcircuit::promptimportbackground}
 $m add command -label "Execute Script" -command {xcircuit::promptexecscript}
+$m add command -label "Tcl Console" -command {xcircuit::consoleup}
 $m add command -label "Write XCircuit PS" -command {xcircuit::promptsavepage}
 $m add separator
 $m add command -label "Add To Library" -command {xcircuit::promptaddlibrary}
 $m add command -label "Load New Library" -command {xcircuit::promptloadlibrary}
-$m add command -label "Save Library" -command {xcircuit::promptsavelib}
+$m add command -label "Save Library" -command {if {[catch xcircuit::library]} \
+	{xcircuit::promptsavelib [xcircuit::library "User Library"]} \
+	{xcircuit::promptsavelib [xcircuit::library]}}
 $m add separator
 $m add command -label "Clear Page" -command {xcircuit::page reset}
 $m add separator
@@ -1162,9 +1166,9 @@ $m add cascade -label "Encoding" -menu $m.encodingmenu
 $m add cascade -label "Insert" -menu $m.insertmenu
 $m add cascade -label "Justification" -menu $m.justifymenu
 $m add command -label "Parameterize" \
-	-command {xcircuit::label parameter make substring}
+	-command {xcircuit::parameter make substring}
 $m add command -label "Unparameterize" \
-	-command {xcircuit::label parameter forget substring}
+	-command {xcircuit::parameter forget substring}
 $m add separator
 $m add command -label "Make Label" -command {xcircuit::label make}
 
@@ -1299,7 +1303,7 @@ $m3 add separator
 $m3 add check -label "Closed" -variable polyclosed -onvalue closed \
 	-offvalue unclosed -command {xcircuit::border  $polyclosed}
 $m3 add check -label "Bounding Box" -variable bboxtype -onvalue true \
-	-offvalue false -command {xcircuit::borderr bbox $bboxtype}
+	-offvalue false -command {xcircuit::border bbox $bboxtype}
 
 # stipple images
 image create bitmap img_stip0 -foreground white -background black -file \
@@ -1476,5 +1480,9 @@ bind .xcircuit.mainframe.mainarea.drawing <Enter> {focus %W}
 
 tkwait visibility .xcircuit.mainframe.mainarea.drawing
 
+# This pops down the interpreter window, if the "console.tcl" script was run.
+
+catch xcircuit::consoledown
+
 # End of GUI configuration file.  Xcircuit continues to load the xcircuit
 # startup configuration files.
